Site Designer Goals
===================

Provide an integrated look and feel for site content
----------------------------------------------------

* **XXX** :doc:`CreateNewSkin`

  * portal_skins Properties tab. Discussion of Layers and their order of
    precedence.

  * Creating a new layer. Difference between file system layers vs TTW
    layers. Don't document actually creating a file system layer, this should
    likely be a separate use case that refers back to this one.

  * The theory behind customizing methods, but don't refer to specific
    layers or specific methods/images.

* **XXX** :doc:`ChangeSkinLookAndFeel`

  * Brief description of customizing methods. Refer back to "Create new
    skin for the site".

  * Document each layer that deals with appearance with a description of
    each constituent object (method, image, ...)

Give end users an effective way to navigate the site
----------------------------------------------------

* **XXX** :doc:`ChangeSkinBehavior`

  * Brief description of customizing methods. Refer back to "Create new
    skin for the site description".

  * Document each layer that deals with behavior with a description of each
    method.

Keep the site fresh and interesting for end users
-------------------------------------------------

* **XXX** :doc:`ChangeDefaultSiteSkin`

  * Brief description of skins. Refer back to other skin use cases.

  * portal_skin Properties tab, bottom half.  Very simple form.
